pub type Result<T> = Result<T, Error>;Expand description
Type alias for Result<T, gonfig::Error>.
This is a convenience type that you can use throughout your application when working with gonfig operations.
Examples
use gonfig::Result;
struct MyConfig;
impl MyConfig {
fn from_gonfig() -> Result<Self> { Ok(MyConfig) }
}
fn load_config() -> Result<MyConfig> {
MyConfig::from_gonfig()
}Aliased Type
pub enum Result<T> {
Ok(T),
Err(Error),
}